/************************************************************
 *
 * 1999 - 2004 (c) Intersect Alliance Pty Ltd.
 *
 * These routines populate the audit objective window, from
 * the configuration file.
 *
 *
 * SNARE GUI Version 2.4
 *
 ************************************************************/

void update_objective_window(gchar *, gchar *, gchar *, gchar *, gchar *,
			     gchar *, gchar *, gint);
void populate_combo_list(GtkWidget *);
